@@ -139,7 +139,8 @@ _tbz2_write_file(FILE *src, int dir_fd, const char *dst, size_t len)
 	FILE *out;
 
 	if (!dst) {
-		fseek(src, len, SEEK_CUR);
+		if (fseek(src, len, SEEK_CUR) == -1)
+			errp("cannot seek to pos %zd: %s", len, strerror(errno));
 		return;
 	}
 
